%global gangver     3.7.2
%global webver      3.7.5

%global systemd         1
%global _hardened_build 1

Summary:            Distributed Monitoring System
Name:               ganglia
Version:            %{gangver}
Release:            4%{?dist}
License:            BSD
URL:                http://ganglia.sourceforge.net/
Source0:            http://downloads.sourceforge.net/sourceforge/ganglia/ganglia-%{version}.tar.gz
Source1:            https://github.com/ganglia/ganglia-web/archive/%{webver}/ganglia-web-%{webver}.tar.gz
Source2:            gmond.service
Source3:            gmetad.service
Source4:            ganglia-httpd24.conf.d
Source5:            ganglia-httpd.conf.d
Source6:            conf.php
Patch3000:          ganglia-web-3.7.2-path.patch
Patch3001:          ganglia-3.7.2-apache.patch
Patch3002:          ganglia-3.7.2-sflow.patch
Patch3003:          ganglia-3.7.2-tirpc-hack.patch
Patch3004:          ganglia-web-5ee6b7.patch

BuildRequires:      gcc, make, libtool, automake, autoconf
BuildRequires:      systemd, rpcgen, rsync, perl-podlators, perl-Pod-Html
BuildRequires:      libtirpc-devel, cyrus-sasl-devel, expat-devel, freetype-devel, libart_lgpl-devel, libconfuse-devel, libmemcached-devel, libpng-devel, pcre-devel, rrdtool-devel, apr-devel >= 1, libuuid-devel

%description
Ganglia is a scalable, real-time monitoring and execution environment
with all execution requests and statistics expressed in an open
well-defined XML format.

%package            web
Summary:            Ganglia Web Frontend
Version:            %{webver}
Requires:           rrdtool
Requires:           php
Requires:           php-gd
Requires:           %{name}-gmetad = %{gangver}-%{release}
Requires:           php-xml

%description        web
This package provides a web frontend to display the XML tree published
by ganglia, and to provide historical graphs of collected
metrics. This website is written in the PHP.

%package            gmetad
Summary:            Ganglia Metadata collection daemon
Requires:           %{name} = %{gangver}-%{release}
Requires(post):     systemd
Requires(preun):    systemd
Requires(postun):   systemd

%description        gmetad
Ganglia is a scalable, real-time monitoring and execution environment
with all execution requests and statistics expressed in an open
well-defined XML format.

This gmetad daemon aggregates monitoring data from several clusters to
form a monitoring grid. It also keeps metric history using rrdtool.

%package            gmond
Summary:            Ganglia Monitoring daemon
Requires:           %{name} = %{gangver}-%{release}
Requires(post):     systemd
Requires(preun):    systemd
Requires(postun):   systemd

%description        gmond
Ganglia is a scalable, real-time monitoring and execution environment
with all execution requests and statistics expressed in an open
well-defined XML format.

This gmond daemon provides the ganglia service within a single cluster
or Multicast domain.

%package            devel
Summary:            Ganglia Library
Requires:           %{name} = %{gangver}-%{release}
Requires:           apr-devel
Requires:           libconfuse-devel

%description        devel
The Ganglia Monitoring Core library provides a set of functions that
programmers can use to build scalable cluster or grid applications



%prep
%setup -q
install -m 0644 %{SOURCE2} gmond/gmond.service.in
install -m 0644 %{SOURCE3} gmetad/gmetad.service.in
%patch3001 -p0
%patch3002 -p0
%patch3003 -p1

%setup -q -T -D -a 1
mv ganglia-web-%{webver} web
pushd web
%patch3000 -p1
%patch3004 -p1
popd



%build
touch Makefile.am
aclocal -I m4
autoheader
automake --add-missing --copy --foreign 2>/dev/null
libtoolize --automake --copy
automake --add-missing --copy --foreign
autoconf -f || exit 1

pushd libmetrics
aclocal -I m4
autoheader
automake --add-missing --copy --foreign 2>/dev/null
libtoolize --automake --copy
automake --add-missing --copy --foreign
autoconf -f || exit 1
popd

export CFLAGS="%{optflags} -fcommon"
%configure \
    --enable-setuid=ganglia \
    --enable-setgid=ganglia \
    --with-gmetad \
    --with-memcached \
    --disable-static \
    --enable-shared \
    --disable-python \
    --sysconfdir=%{_sysconfdir}/ganglia

%{__sed} -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
%{__sed} -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%{__perl} -pi.orig -e 's|nobody|ganglia|g' \
    gmond/gmond.conf.html ganglia.html gmond/conf.pod

%{__perl} -pi.orig -e 's|.*setuid_username.*|setuid_username ganglia|' \
    gmetad/gmetad.conf.in

%{__perl} -pi.orig -e 's|2345|-|g' gmond/gmond.init gmetad/gmetad.init

%{make_build}



%install
%{make_install}

mkdir -p %{buildroot}%{_localstatedir}/lib/%{name}/rrds

install -Dp -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/gmond.service
install -Dp -m 0644 %{SOURCE3} %{buildroot}%{_unitdir}/gmetad.service

LD_LIBRARY_PATH=lib/.libs gmond/gmond -t | %{__perl} -pe 's|nobody|ganglia|g' \
    > %{buildroot}%{_sysconfdir}/ganglia/gmond.conf

pushd web
make install DESTDIR=%{buildroot}
install -p -m 0644 %{SOURCE6} %{buildroot}%{_sysconfdir}/ganglia/conf.php
ln -s ../../..%{_sysconfdir}/%{name}/conf.php \
    %{buildroot}%{_datadir}/%{name}/conf.php
popd

install -Dp -m 0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/httpd/conf.d/%{name}.conf

rm -f %{buildroot}%{_sysconfdir}/ganglia/conf.d/{modgstatus,example}.conf

rm -rf %{buildroot}%{_datadir}/%{name}/{Makefile*,debian,ganglia-web.spec*,ganglia-web}
rm -rf %{buildroot}%{_datadir}/%{name}/{conf_default.php.in,version.php.in}
rm -rf %{buildroot}%{_localstatedir}/lib/%{name}-web/conf/sql

rm -rf %{buildroot}%{_datadir}/%{name}/{README,TODO,AUTHORS,COPYING}

rm -f %{buildroot}%{_libdir}/*.la

chmod 0644 %{buildroot}%{_datadir}/%{name}/header.php
chmod 0644 %{buildroot}%{_datadir}/%{name}/css/smoothness/jquery-ui-1.10.2.custom.css
chmod 0644 %{buildroot}%{_datadir}/%{name}/css/smoothness/jquery-ui-1.10.2.custom.min.css



%pre
/usr/sbin/useradd -c "Ganglia Monitoring System" \
        -s /sbin/nologin -r -d %{_localstatedir}/lib/%{name} ganglia 2> /dev/null || :

%post gmond
%systemd_post gmond.service

%preun gmond
%systemd_preun gmond.service

%postun gmond
%systemd_postun_with_restart gmond.service

%post gmetad
%systemd_post gmetad.service

%preun gmetad
%systemd_preun gmetad.service

%postun gmetad
%systemd_postun_with_restart gmetad.service

%pretrans web -p <lua>
path = "/usr/share/ganglia/lib/Zend"
st = posix.stat(path)
if st and st.type == "link" then
  os.remove(path)
end



%files
%license COPYING
%doc AUTHORS NEWS README ChangeLog
%{_libdir}/libganglia*.so.*
%dir %{_libdir}/ganglia
%{_libdir}/ganglia/*.so

%files gmetad
%{_sbindir}/gmetad
%{_unitdir}/gmetad.service
%{_mandir}/man1/gmetad.1*
%{_mandir}/man1/gmetad.py.1*
%dir %{_localstatedir}/lib/%{name}
%attr(0755,ganglia,ganglia) %{_localstatedir}/lib/%{name}/rrds
%dir %{_sysconfdir}/ganglia
%config(noreplace) %{_sysconfdir}/ganglia/gmetad.conf

%files gmond
%{_bindir}/gmetric
%{_bindir}/gstat
%{_sbindir}/gmond
%{_unitdir}/gmond.service
%{_mandir}/man5/gmond.conf.5*
%{_mandir}/man1/gmond.1*
%{_mandir}/man1/gstat.1*
%{_mandir}/man1/gmetric.1*
%dir %{_sysconfdir}/ganglia
%config(noreplace) %{_sysconfdir}/ganglia/gmond.conf

%files devel
%{_bindir}/ganglia-config
%{_libdir}/libganglia*.so
%{_includedir}/*.h

%files web
%license web/COPYING
%doc web/AUTHORS web/README web/TODO
%config(noreplace) %{_sysconfdir}/%{name}/conf.php
%config(noreplace) %{_sysconfdir}/httpd/conf.d/%{name}.conf
%{_datadir}/%{name}
%dir %attr(0755,apache,apache) %{_localstatedir}/lib/%{name}-web/conf
%config(noreplace) %attr(0644,apache,apache) %{_localstatedir}/lib/%{name}-web/conf/*.json
%dir %attr(0755,apache,apache) %{_localstatedir}/lib/%{name}-web/dwoo
%dir %attr(0755,apache,apache) %{_localstatedir}/lib/%{name}-web/dwoo/cache
%dir %attr(0755,apache,apache) %{_localstatedir}/lib/%{name}-web/dwoo/compiled



%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.7.2-4
- Rebuilt for OpenCloudOS Stream 23.09

* Thu Aug 17 2023 kianli@tencent.com - 3.7.2-3
- Rebuilt for apr 1.7.4

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.7.2-2
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Mar 29 2023 Zhao Zhen <jeremiazhao@tencent.com> - 3.7.2-1
- initial
